@@ -3,6 +3,7 @@ package Dancer::Plugin::Database;
 use strict;
 use Dancer::Plugin;
 use DBI;
+use Dancer::Plugin::Database::Handle;
 
 =head1 NAME
 
@@ -10,7 +11,7 @@ Dancer::Plugin::Database - easy database connections for Dancer applications
 
 =cut
 
-our $VERSION = '0.09_3';
+our $VERSION = '0.12_01';
 
 my $settings = undef;
 
@@ -43,7 +44,7 @@ register database => sub {
                     "Database connection went away, reconnecting"
                 );
                 if ($handle->{dbh}) { $handle->{dbh}->disconnect; }
-                return $handle->{dbh}= _get_connection();
+                return $handle->{dbh}= _get_connection($settings);
             }
         }
     } else {
@@ -112,7 +113,9 @@ sub _get_connection {
         }
     }
 
-    return $dbh;
+    # Re-bless it as a Dancer::Plugin::Database::Handle object, to provide nice
+    # extra features:
+    return bless $dbh, 'Dancer::Plugin::Database::Handle';
 }
 
 
@@ -164,11 +167,20 @@ sub _get_settings {
             );
         }
     }
-    
+
     # We should have soemthing to return now; remove any unrelated connections
     # (only needed if this is the default connection), and make sure we have a
-    # connection_check_threshold, then return what we found
+    # connection_check_threshold, then return what we found.  In previous
+    # versions the documentation contained a typo mentioning
+    # connectivity-check-threshold, so support that as an alias.
     delete $return_settings->{connections};
+    if (exists $return_settings->{'connectivity-check-threshold'}
+        && !exists $return_settings->{connection_check_threshold})
+    {
+        $return_settings->{connection_check_threshold}
+            = delete $return_settings->{'connectivity-check-threshold'};
+    }
+
     $return_settings->{connection_check_threshold} ||= 30;
     return $return_settings;
 
@@ -180,7 +192,7 @@ sub _get_settings {
     use Dancer;
     use Dancer::Plugin::Database;
 
-    # Calling the database keyword will get you a connected DBI handle:
+    # Calling the database keyword will get you a connected database handle:
     get '/widget/view/:id' => sub {
         my $sth = database->prepare(
             'select * from widgets where id = ?',
@@ -189,6 +201,12 @@ sub _get_settings {
         template 'display_widget', { widget => $sth->fetchrow_hashref };
     };
 
+    # The handle is a Dancer::Plugin::Database::Handle object, which subclasses
+    # DBI's DBI::db handle and adds a few convenience features, for example:
+    get '/insert/:name' => sub {
+        database->quick_insert('people', { name => params->{name} });
+    };
+
     dance;
 
 Database connection details are read from your Dancer application config - see
@@ -198,7 +216,12 @@ below.
 =head1 DESCRIPTION
 
 Provides an easy way to obtain a connected DBI database handle by simply calling
-the database keyword within your L<Dancer> application.
+the database keyword within your L<Dancer> application
+
+Returns a L<Dancer::Plugin::Database::Handle> object, which is a subclass of
+L<DBI>'s L<DBI::db> connection handle object, so it does everything you'd expect
+to do with DBI, but also adds a few convenience methods.  See the documentation
+for L<Dancer::Plugin::Database::Handle> for full details of those.
 
 Takes care of ensuring that the database handle is still connected and valid.
 If the handle was last asked for more than C<connection_check_threshold> seconds
@@ -220,13 +243,13 @@ should be specified as, for example:
             host: 'localhost'
             username: 'myusername'
             password: 'mypassword'
-            connectivity-check-threshold: 10
+            connection_check_threshold: 10
             dbi_params:
                 RaiseError: 1
                 AutoCommit: 1
             on_connect_do: ["SET NAMES 'utf8'", "SET CHARACTER SET 'utf8'" ]
 
-The C<connectivity-check-threshold> setting is optional, if not provided, it
+The C<connection_check_threshold> setting is optional, if not provided, it
 will default to 30 seconds.  If the database keyword was last called more than
 this number of seconds ago, a quick check will be performed to ensure that we
 still have a connection to the database, and will reconnect if not.  This
@@ -284,6 +307,28 @@ CONNECTIONS', then calling the database() keyword with the name of the
 connection as specified in the config file will get you a database handle
 connected with those details.
 
+
+=head1 CONVENIENCE FEATURES (quick_update, quick_insert, quick_delete)
+
+The handle returned by the C<database> keyword is a
+L<Dancer::Plugin::Database::Handle> object, which subclasses the C<DBI::db> DBI
+connection handle.  This means you can use it just like you'd normally use a DBI
+handle, but extra convenience methods are provided, as documented in the POD for
+L<Dancer::Plugin::Database::Handle>.
+
+Examples:
+
+  # Update the row where the 'id' column is '42', setting the 'foo' column to
+  # 'Bar':
+  database->quick_update($table_name, { id => 42 }, { foo => 'Bar');
+
+  # Insert a new row, using a named connection (see above)
+  database('connectionname')->quick_insert($table_name, { foo => 'Bar' });
+
+  # Delete the row with id 42:
+  database->quick_delete($table_name, { id => 42 });
+
+
 =head1 AUTHOR
 
 David Precious, C<< <davidp@preshweb.co.uk> >>
